/**
 * 批处理和并发控制工具
 * 优化API请求性能和资源利用
 */
interface BatchProcessorOptions {
    batchSize: number;
    maxWaitTime: number;
    maxConcurrency: number;
    retryAttempts: number;
    retryDelay: number;
}
/**
 * 智能批处理器
 */
export declare class BatchProcessor<T, R> {
    private processor;
    private queue;
    private processing;
    private options;
    private activeBatches;
    constructor(processor: (batch: T[]) => Promise<R[]>, options?: Partial<BatchProcessorOptions>);
    /**
     * 添加请求到批处理队列
     */
    add(input: T): Promise<R>;
    /**
     * 调度批处理
     */
    private scheduleProcessing;
    /**
     * 处理批次
     */
    private processBatch;
    /**
     * 执行批次处理
     */
    private executeBatch;
    /**
     * 生成唯一ID
     */
    private generateId;
    /**
     * 延迟函数
     */
    private delay;
    /**
     * 获取队列状态
     */
    getStatus(): {
        queueLength: number;
        activeBatches: number;
        processing: boolean;
    };
    /**
     * 清空队列
     */
    clear(): void;
}
/**
 * 并发控制器
 */
export declare class ConcurrencyController {
    private maxConcurrency;
    private running;
    private queue;
    constructor(maxConcurrency?: number);
    /**
     * 执行任务
     */
    execute<T>(task: () => Promise<T>): Promise<T>;
    /**
     * 处理队列
     */
    private processQueue;
    /**
     * 获取状态
     */
    getStatus(): {
        running: number;
        queued: number;
        maxConcurrency: number;
    };
}
/**
 * 请求去重器
 */
export declare class RequestDeduplicator<T> {
    private pendingRequests;
    /**
     * 执行去重请求
     */
    execute(key: string, factory: () => Promise<T>): Promise<T>;
    /**
     * 获取状态
     */
    getStatus(): {
        pendingCount: number;
        pendingKeys: string[];
    };
    /**
     * 清空所有待处理请求
     */
    clear(): void;
}
/**
 * 智能重试器
 */
export declare class SmartRetry {
    static execute<T>(operation: () => Promise<T>, options?: {
        maxAttempts?: number;
        baseDelay?: number;
        maxDelay?: number;
        backoffFactor?: number;
        shouldRetry?: (error: any) => boolean;
    }): Promise<T>;
}
export declare const globalConcurrencyController: ConcurrencyController;
export declare const globalRequestDeduplicator: RequestDeduplicator<unknown>;
export declare function createArticleBatchProcessor(): BatchProcessor<string, any>;
export declare function createPinBatchProcessor(): BatchProcessor<string, import("../types/index.js").PinInfo>;
export declare function createUserBatchProcessor(): BatchProcessor<string, import("../types/index.js").UserInfo>;
export {};
