/**
 * 性能监控和分析工具
 * 提供详细的性能指标收集和分析
 */
interface PerformanceMetric {
    name: string;
    startTime: number;
    endTime?: number;
    duration?: number;
    metadata?: Record<string, any>;
}
interface PerformanceStats {
    count: number;
    totalDuration: number;
    averageDuration: number;
    minDuration: number;
    maxDuration: number;
    p50: number;
    p95: number;
    p99: number;
}
/**
 * 性能监控器
 */
export declare class PerformanceMonitor {
    private metrics;
    private activeMetrics;
    private maxMetrics;
    constructor(maxMetrics?: number);
    /**
     * 开始性能测量
     */
    start(name: string, metadata?: Record<string, any>): string;
    /**
     * 结束性能测量
     */
    end(id: string): number | null;
    /**
     * 测量函数执行时间
     */
    measure<T>(name: string, fn: () => Promise<T>, metadata?: Record<string, any>): Promise<T>;
    /**
     * 测量同步函数执行时间
     */
    measureSync<T>(name: string, fn: () => T, metadata?: Record<string, any>): T;
    /**
     * 添加指标
     */
    private addMetric;
    /**
     * 获取指标统计
     */
    getStats(name?: string): Record<string, PerformanceStats>;
    /**
     * 获取最近的指标
     */
    getRecentMetrics(count?: number): PerformanceMetric[];
    /**
     * 获取慢查询
     */
    getSlowOperations(threshold?: number): PerformanceMetric[];
    /**
     * 清空指标
     */
    clear(): void;
    /**
     * 生成性能报告
     */
    generateReport(): any;
    /**
     * 生成性能建议
     */
    private generateRecommendations;
    /**
     * 计算百分位数
     */
    private percentile;
    /**
     * 分组函数
     */
    private groupBy;
}
/**
 * 性能装饰器
 */
export declare function performanceMonitor(name?: string): (target: any, propertyKey: string, descriptor: PropertyDescriptor) => PropertyDescriptor;
/**
 * 内存使用监控
 */
export declare class MemoryMonitor {
    private samples;
    private maxSamples;
    constructor(maxSamples?: number);
    /**
     * 采样内存使用
     */
    sample(): void;
    /**
     * 获取内存统计
     */
    getStats(): any;
    /**
     * 格式化字节数
     */
    private formatBytes;
}
export declare const globalPerformanceMonitor: PerformanceMonitor;
export declare const globalMemoryMonitor: MemoryMonitor;
export declare function runPerformanceBenchmark(): Promise<void>;
export {};
